/* ************************************************************************
 * Copyright 2006 Lucio Benfante
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *    http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *********************************************************************** */
package com.benfante.splasher.example;

import com.benfante.splasher.task.AbstractTask;

/**
 * A fake initialization task that simply repeat a sleep of 100 milliseconds.
 *
 * @author Lucio Benfante <a href="mailto:lucio@benfante.com">lucio@benfante.com</a>
 * @version $Id: FakeTask.java,v 1.1.1.1 2006-04-01 05:41:35 lucio Exp $
 */
public class FakeTask extends AbstractTask {
    
    private int repetitions;
    
    /**
     * Creates a new instance of FakeTask
     *
     * @param repetitions The number of repetitions for the sleep
     * @param description A description for the task
     */
    public FakeTask(int repetitions, String description) {
        super(description, repetitions);
        this.repetitions = repetitions;
    }
    
    /**
     * Execution of the task.
     * Repeat a sleep of 100 milliseconds, notifying the task observer(s)
     * at each iteration.
     */
    public void run() {
        notifyChanges();
        for (int i = 1; i <= this.repetitions; i++) {
            try { Thread.sleep(100); } catch(InterruptedException e) {}
            completed = i*100/repetitions;
            notifyChanges();
        }
    }
    
}
