/* ************************************************************************
 * Copyright 2006 Lucio Benfante
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *********************************************************************** */
package com.benfante.splasher.example;

import com.benfante.splasher.SimpleSplashManager;
import com.benfante.splasher.task.SimpleTask;
import java.awt.Color;
import java.awt.Font;

/**
 * A simple example of a splash screen in Java 6.
 *
 * It must be execute using the following command:
 *
 * <code>java -splash:benfante/splasher/example/SplasherDemo.png com.benfante.splasher.example.MainWindow</code>
 *
 * @author Lucio Benfante <a href="mailto:lucio@benfante.com">lucio@benfante.com</a>
 * @version $Id: MainWindow.java,v 1.1.1.1 2006-04-01 05:41:35 lucio Exp $
 */
public class MainWindow extends javax.swing.JFrame {
    
    /** Creates new form MainWindow */
    public MainWindow() {
        initComponents();
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        jLabel1 = new javax.swing.JLabel();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("Splasher Demo");
        setLocationByPlatform(true);
        setMinimumSize(new java.awt.Dimension(200, 200));
        jLabel1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel1.setText("Programma avviato!");
        jLabel1.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        getContentPane().add(jLabel1, java.awt.BorderLayout.CENTER);

        pack();
    }// </editor-fold>//GEN-END:initComponents
    
    /**
     * @param args the command line arguments
     */
    public static void main(String args[]) {
        // Create and initialize the SimpleSplashManager
        SimpleSplashManager ssm = new SimpleSplashManager();
        ssm.setProgressBarColor(Color.ORANGE);
        ssm.setMessageColor(Color.YELLOW);
        ssm.setMessageFont(new Font(Font.DIALOG, Font.BOLD, 12));
        
        // Some fake initialization tasks
        FakeTask t1 = new FakeTask(30, "Executing task 1...");
        t1.add(ssm);

        FakeTask t2 = new FakeTask(20, "Executing task 2...");
        t2.add(ssm);

        FakeTask t3 = new FakeTask(10, "Executing task 3...");
        t3.add(ssm);
        
        // Run the tasks
        t1.run();
        t2.run();
        t3.run();
        
        // Wait a little more
        try { Thread.sleep(2000); } catch(InterruptedException e) {}
        
        // Show the application main window
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new MainWindow().setVisible(true);
            }
        });
    }
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel jLabel1;
    // End of variables declaration//GEN-END:variables
    
}
