/* ************************************************************************
 * Copyright 2006 Lucio Benfante
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *********************************************************************** */
package com.benfante.splasher.task;

import java.util.ArrayList;
import java.util.List;

/**
 * A simple atomic task.
 * It notifies the observer(s) at the start and after the completion.
 *
 * @author Lucio Benfante <a href="mailto:lucio@benfante.com">lucio@benfante.com</a>
 * @version $Id: SimpleTask.java,v 1.2 2006-04-01 07:02:28 lucio Exp $
 */
public class SimpleTask extends AbstractTask {
    
    private Runnable code;
    
    /**
     * Creates a new instance of SimpleTask
     *
     * @param code The code executed by the task
     * @param description A description for the task
     * @param weight The weight of this task (relative to the other tasks)
     */
    public SimpleTask(Runnable code, String description, int weight) {
        super(description, weight);
        this.code = code;
    }

    /**
     * Execute the task
     */
    public void run() {
        notifyChanges();
        code.run();
        completed = COMPLETED;
        notifyChanges();
    }
    
}
